@@ -2,8 +2,8 @@ import warnings
 
 import pandas as pd
 
-from jaseci.actions.live_actions import jaseci_action
-from jaseci.actions.remote_actions import launch_server
+from jaseci.jsorc.live_actions import jaseci_action
+from jaseci.jsorc.remote_actions import launch_server
 from fastapi import HTTPException
 
 from .action_utils import (
